@@ -51,6 +51,8 @@ class IconGrid(object):	#(gobject.GObject):
     def __init__(self, isconfig=False):
 #	self.__gobject_init__()
 
+	self.init_done=False
+
 	self.size=(0,0)
 
 	self.isconfig=isconfig
@@ -60,12 +62,22 @@ class IconGrid(object):	#(gobject.GObject):
 
 	self.draw_pending=False
 
+	self.mode=None
+
+	# If this is False then animations are forcefully disabled
+	self.do_animations=True
+
+	self.angle_timer_start=0
+
+	# Duration of the rotation effect
+	self.rotation_time=0.8
+
     def do_realize(self, config):
 	self.config=config
 
 	self.icons=Icons(self.isconfig, self.config)
 	self.setMode('l')
-	self.setSize((4,4))
+	self.setSize((8,4))
 	self.reloadIcons()
 
     def connect(self, what, *args):
@@ -83,19 +95,90 @@ class IconGrid(object):	#(gobject.GObject):
 	return(ret)
 
     def setMode(self, mode):
+	if self.mode==mode:
+	    print "same mode"
+	    return
+
 	self.mode=mode
 	if not isinstance(self, gtk.Widget):
 	    return
 
+	do_draw=False
+
 	try:
 	    v=self.get_property('is-on-current-desktop')
 	    if v:
-		self.queue_draw()
+		do_draw=True
 	    else:
 		self.draw_pending=True
 	except TypeError:
+	    do_draw=True
+
+	if do_draw and self.config.getAnimate() and self.do_animations:
+	    #self.queue_draw()
+	    # Don't start another timer
+	    # Instead adjust the time start to produce a nice effect ;-)
+	    if self.angle_timer_start==0:
+		self.angle_timer_start=time.time()
+		gobject.timeout_add(20, self.timerAngle)
+	    else:
+		dt=time.time()-self.angle_timer_start
+		da=90.0*dt/self.rotation_time
+
+		da2=90.0-da
+		dt2=da2*self.rotation_time/90.0
+		self.angle_timer_start=time.time()-dt2
+        else:
+            if self.mode=='l':
+                self.setAngle(0)
+            else:
+                self.setAngle(90)
+
+	    if do_draw:
+		self.queue_draw()
+
+    def disableAnimation(self):
+	self.do_animations=False
+
+    def enableAnimation(self):
+	self.do_animations=True
+
+    def setAnimationEnable(self, value):
+	if value:
+	    self.enableAnimation()
+	else:
+	    self.disableAnimation()
+
+    def timerAngle(self):
+	if self.angle_timer_start==0:
+	    self.angle_timer_start=time.time()-0.05
+
+	dt=time.time()-self.angle_timer_start
+
+	da=90.0*dt/self.rotation_time
+
+	if self.mode=='l':
+	    angle=90-da
+	else:
+	    angle=da
+
+	if angle>=90:
+	    angle=90
+	    ret=False
+	elif angle<0:
+	    angle=0
+	    ret=False
+	else:
+	    ret=True
+
+	if self.setAngle(angle):
 	    self.queue_draw()
 
+	if ret==False:
+	    self.angle_timer_start=0
+
+	return(ret)
+
     def iconAt(self, x, y):
 	""" Get icon at coordinates x,y. X and Y are in pixels """
 
@@ -137,7 +220,23 @@ class IconGrid(object):	#(gobject.GObject):
 		continue
 
 	    ico=self.icons.get(x,y)
-	    ico.draw(cr, x2, y2, self.mode)
+	    ico.draw(cr, x2, y2)
+
+    def setAngle(self, angle):
+	""" Return True/False indicating that angle has changed """
+	ret=False
+	for x,y in self.icons:
+	    ic=self.icons.get(x,y)
+	    if ic.setAngle(angle):
+		ret=True
+
+	return(ret)
+
+    def clearAnimationCache(self):
+	""" Clear animation cache, freeing memory """
+	for x,y in self.icons:
+	    ic=self.icons.get(x,y)
+	    ic.clearAnimationCache()
 
     def do_expose_event(self, event):
 	cr=self.window.cairo_create()
@@ -147,6 +246,10 @@ class IconGrid(object):	#(gobject.GObject):
 
 	cr.clip()
 
+	if not self.init_done:
+	    self.icons.setWindow(self.window)
+	    self.init_done=True
+
 	self._draw(cr, event)
 
     def setLastIcon(self, icon):
@@ -225,21 +328,24 @@ class IconGrid(object):	#(gobject.GObject):
 #	self.setMode(o)
 
 class IconGridWidget(IconGrid, gtk.Widget):
-    def __init__(self, isconfig, config):
+    def __init__(self, isconfig, config, animation=True):
 	IconGrid.__init__(self, isconfig)
 	gtk.Widget.__init__(self)
 
+	# This must be called before do_realize
+	self.setAnimationEnable(animation)
+
 	self.config=config
 
 	IconGrid.do_realize(self, self.config)
 
-	if isconfig:
-	    maxsz=self.config.getMaxSize()
-	    w=maxsz[0] * (self.config.iconsize + self.config.iconspace)
-	    h=maxsz[1] * (self.config.iconsize + self.config.iconspace)
-	else:
-	    w=self.size[0] * (self.config.iconsize + self.config.iconspace)
-	    h=self.size[1] * (self.config.iconsize + self.config.iconspace)
+	self.setSize(self.size)
+
+    def setSize(self, size):
+	IconGrid.setSize(self, size)
+
+	w=self.size[0] * (self.config.iconsize + self.config.iconspace)
+	h=self.size[1] * (self.config.iconsize + self.config.iconspace)
 
 	self.set_size_request(w, h)
 
