@@ -65,7 +65,8 @@ class DrlaunchPlugin(IconGrid, HomePluginItem, FremantleRotation):
     def __init__(self):
 	IconGrid.__init__(self)
 	HomePluginItem.__init__(self)
-	FremantleRotation.__init__(self, 'DrlaunchPlugin')
+	FremantleRotation.__init__(self, 'DrlaunchPlugin',
+	    mode=FremantleRotation.AUTOMATIC, dontrotate=True)
 
 	self.winConfig=None
 
@@ -159,12 +160,17 @@ class DrlaunchPlugin(IconGrid, HomePluginItem, FremantleRotation):
 	config.setApps(dt['apps'])
 	config.setIndiv(dt['indiv'])
 	config.setLongpress(dt['longpress'])
+	config.setAnimate(dt['animate'])
 	config.save()
 	
 	# Resize widget
 	self.setSize(dt['size'])
 	self.reloadIcons()
 
+	# Free memory that is used for animations if animations are disabled
+	if not dt['animate']:
+	    self.clearAnimationCache()
+
 	self.queue_draw()
 
     def handle_click(self, sender, icon):
